# Copyright (C) Softhealer Technologies.


from odoo import models, fields


class ShWqmQuickMenu(models.Model):
    _name = "sh.wqm.quick.menu"
    _description = "quick / Shortcut menu model"
    _order = "id desc"

    menu_id = fields.Many2one(comodel_name="ir.ui.menu",
                              string="Menu",
                              ondelete='cascade')
    user_id = fields.Many2one(comodel_name="res.users",
                              string="User",
                              required=True,
                              ondelete='cascade')

    parent_menu_id = fields.Integer(string="Parent Menu ID")
    sh_url = fields.Char("Url ")
    name = fields.Char("Name")

    def set_quick_menu(self, action_id,parent_menu_id):
        if action_id:
            menu = self.env['ir.ui.menu'].sudo().search([('action', 'like', '%,' + str(action_id))], limit=1)
            if not menu:
                action = self.env['ir.actions.actions'].sudo().browse(int(action_id))
                if action:
                    menu = self.env['ir.ui.menu'].sudo().search([('name', '=', action.name), ('action', '!=', '')], limit=1)

            
            if menu:
                rec = self.sudo().search(
                    [('menu_id', '=', menu.id),
                     ('user_id', '=', self.env.user.id)])
                if (rec):
                    if (rec.sudo().unlink()):
                        return {
                            'is_set_quick_menu': False
                        }
                else:
                    if (menu and menu.action):
                        if (self.sudo().create({
                            'menu_id': menu.id,
                            'user_id': self.env.user.id,
                            'parent_menu_id' : int(parent_menu_id),
                        })):
                            return {
                                'is_set_quick_menu': True
                            }
        return {}

    def set_quick_url(self, url, model, res_id, action_id):
        bookmark_name = ''
        if model and res_id:
            read_data = self.env[model].sudo().search_read([('id','=',res_id)],[],order='id')
            if len(read_data) > 0:
                if 'name' in read_data[0]:
                    bookmark_name = read_data[0]['name']
                elif 'display_name' in read_data[0]:
                    bookmark_name = read_data[0]['display_name']
                elif 'reference' in read_data[0]:
                    bookmark_name = read_data[0]['reference']
                elif 'id' in read_data[0]:
                    bookmark_name = read_data[0]['id']

        elif action_id:
            action = self.env['ir.actions.act_window'].sudo().browse(int(action_id))
            if action:
                bookmark_name = action.name

        if url:
             
            
            rec = self.sudo().search(
                [('sh_url', '=', url),
                    ('user_id', '=', self.env.user.id)])
            if (rec):
                if (rec.sudo().unlink()):
                    return {
                        'is_set_quick_menu': False
                    }
            else:
                if (url):
                    if (self.sudo().create({
                        'sh_url': url,
                        'name': bookmark_name,
                        'user_id': self.env.user.id,
                    })):
                        return {
                            'is_set_quick_menu': True
                        }
        return {}

    def is_quick_menu_avail(self, action_id):
        if action_id:
            menu = self.env['ir.ui.menu'].sudo().search([('action', 'like', '%,' + str(action_id))], limit=1)
#             menu = False
            if not menu:
                action = self.env['ir.actions.actions'].sudo().browse(int(action_id))
                if action:
                    menu = self.env['ir.ui.menu'].sudo().search([('name', '=', action.name), ('action', '!=', '')], limit=1)
            
            if menu:
                result = self.is_already_have_in_quick_menu(menu.id)
                return result 
                
    def is_quick_menu_avail_url(self, url):
        if url:
          
            result = self.is_already_have_in_quick_url(url)
            return result       

    def is_already_have_in_quick_menu(self, menu_id):
        menu = self.env['ir.ui.menu'].sudo().browse(int(menu_id))
        if (menu and menu.action):
            rec = self.sudo().search(
                [('menu_id', '=', menu_id),
                 ('user_id', '=', self.env.user.id)])
            if (rec):
                return True
        return False
    
    def is_already_have_in_quick_url(self, url):        
        if (url):
            rec = self.sudo().search(
                [('sh_url', '=', url),
                 ('user_id', '=', self.env.user.id)])
            if (rec):
                return True
        return False

    def get_quick_menu_data(self, fields=[]): 
        search_quick_menu = self.sudo().search([
            ('user_id', '=', self.env.user.id),
            ])
        final_quick_menu_list = []
        if search_quick_menu:
            for rec in search_quick_menu:
                vals = {
                    'id'             : rec.id,
                    'name'           : rec.name,
                    'sh_url'      : rec.sh_url,
                    }
                final_quick_menu_list.append(vals)
                
        return final_quick_menu_list

    def remove_quick_menu_data(self, menu_id):
        if menu_id:
            rec = self.sudo().search(
                [('id', '=', menu_id),
                 ('user_id', '=', self.env.user.id)])
            if rec:
                json = {
                    'id': rec.id,
                    'name': rec.name,
                    'sh_url': rec.sh_url,
                }
                rec.sudo().unlink()
                return json
        return False

class ResUsers(models.Model):
    _inherit = "res.users"

    sh_wqm_web_quick_menu_line = fields.One2many(comodel_name="sh.wqm.quick.menu",
                                                 inverse_name="user_id",
                                                 string="Quick Menu",
                                                 )
