//===========================================
//toggle switch if quick menu already exists
//===========================================
odoo.define("sh_web_quick_menu.quick_menu_already", function (require) {
    "use strict";
    var core = require("web.core");
    var Dialog = require("web.Dialog");
    var Widget = require("web.Widget");
    var rpc = require("web.rpc");
    var SystrayMenu = require("web.SystrayMenu");
    var menu = require("web.Menu");
    var ActionManager = require("web.ActionManager");
    var _t = core._t;
    var QWeb = core.qweb;

    var ActionManager = ActionManager.include({
        _preprocessAction: function (action, options) {
            var self = this;
            this._super.apply(this, arguments);

            // 获取基础路径和哈希部分
            var baseUrl = "/web"; // 固定的基础路径
            var hashPart = window.location.hash; // 获取 URL 的哈希部分
            var sh_url = baseUrl + hashPart; // 拼接基础路径和哈希部分

            if (sh_url) {
                rpc.query({
                    model: 'sh.wqm.quick.menu',
                    method: 'is_quick_menu_avail_url',
                    args: ['', sh_url]
                }).then(function (rec) {
                    if (rec) {
                        $('.o_user_bookmark_menu > a').addClass('active');
                    } else {
                        $('.o_user_bookmark_menu > a').removeClass('active');
                    }
                });
            }
        },
    });

    var menu = menu.include({
        getMenuRecord: function (menu_id) {
            return rpc.query({
                model: "sh.wqm.quick.menu",
                method: "is_already_have_in_quick_menu",
                args: ["", menu_id],
            });
        },
        _trigger_menu_clicked: function (menu_id, action_id) {
            var self = this;
            this._super.apply(this, arguments);
            this.getMenuRecord(menu_id).then(function (rec) {
                if (rec) {
                    self.$el.find(".o_user_bookmark_menu > a").addClass("active");
                } else {
                    self.$el.find(".o_user_bookmark_menu > a").removeClass("active");
                }
            });
        },
    });
});

//===========================================
//Quick Menu (main on off switch)
//===========================================
odoo.define("sh_web_quick_menu.quick_menu", function (require) {
    "use strict";
    var core = require("web.core");
    var Dialog = require("web.Dialog");
    var Widget = require("web.Widget");
    var rpc = require("web.rpc");
    var SystrayMenu = require("web.SystrayMenu");
    var _t = core._t;
    var QWeb = core.qweb;

    var quick_menu = Widget.extend({
        template: "quick.menu",
        events: {
            click: "on_click",
        },
        init: function () {
            this._super.apply(this, arguments);
        },
        getUrlVars: function () {
            var vars = [], hash;
            var hashes = window.location.href.slice(window.location.href.indexOf('?') + 1).split('&');
            for (var i = 0; i < hashes.length; i++) {
                hash = hashes[i].split('=');
                vars.push(hash[0]);
                vars[hash[0]] = hash[1];
            }
            return vars;
        },
        getUrl: function () {
            var baseUrl = "/web"; // 固定的基础路径
            var hashPart = window.location.hash; // 获取 URL 的哈希部分
            return baseUrl + hashPart; // 拼接基础路径和哈希部分
        },
        start: function () {
            return this._super();
        },
        getMenuRecord: function () {
            var action_id = $.bbq.getState().action;
            console.log(" $.bbq.getState().action", $.bbq.getState().action);
            var model = $.bbq.getState().model;
            var res_id = null;
            if ($.bbq.getState().view_type === 'form') {
                res_id = $.bbq.getState().id;
            }

            // 使用拼接后的 URL
            var sh_url = this.getUrl();
            console.log("name", model, res_id);

            return rpc.query({
                model: 'sh.wqm.quick.menu',
                method: 'set_quick_url',
                args: ['', sh_url, model, res_id, action_id]
            });
        },
        on_click: function (ev) {
            ev.preventDefault();
            var self = this;
            this.getMenuRecord().then(function (rec) {
                if (rec.is_set_quick_menu) {
                    self.$el.find('> a').addClass('active');
                } else {
                    self.$el.find('> a').removeClass('active');
                }
            });
            //refresh the page
            location.reload(true);
        }
    });

    quick_menu.prototype.sequence = 0;
    SystrayMenu.Items.push(quick_menu);
    return {
        quick_menu: quick_menu,
    };
});

// ===========================================
//	Quick Menu List
// ===========================================
odoo.define("sh_web_quick_menu.quick_menulist", function (require) {
    "use strict";
    var core = require("web.core");
    var Dialog = require("web.Dialog");
    var Widget = require("web.Widget");
    var rpc = require("web.rpc");
    var SystrayMenu = require("web.SystrayMenu");
    var _t = core._t;
    var QWeb = core.qweb;

    var quick_menulist = Widget.extend({
        template: "quick.menulist",
        events: {
            "click li.sh_wqm_remove_quick_menu_cls i": "remove_quick_menu",
        },
        remove_quick_menu: function (e) {
            e.stopPropagation();
            var self = this;
            var id = parseInt($(e.currentTarget).data('id'));
            console.log("$(e.currentTarget)", $(e.currentTarget));

            if (!isNaN(id)) {
                rpc.query({
                    model: 'sh.wqm.quick.menu',
                    method: 'remove_quick_menu_data',
                    args: ['', id]
                }).then(function (res) {
                    if (res.id) {
                        if ($.bbq.getState(true).action == res.action_id) {
                            self.$el.parents().find('.o_user_bookmark_menu > a').removeClass('active');
                        }

                        // 直接刷新当前页面
                        window.location.reload();
                    }
                });
            }
            return false;
        },
        init: function () {
            this._super.apply(this, arguments);
        },
        start: function () {
            var self = this;
            var quick_menus_var = rpc.query({
                model: 'sh.wqm.quick.menu',
                method: 'get_quick_menu_data',
                args: ['', ['name', 'sh_url']],
            })
                .then(function (menus) {
                    if (menus.length > 0) {
                        self.$el.find('.sh_wqm_quick_menu_submenu_list_cls').html(QWeb.render("quick.menulist.actions", { 'quick_menulist_actions': menus }));
                    } else {
                        self.$el.find('.sh_wqm_quick_menu_submenu_list_cls').html(QWeb.render("quick.menulist.actions", { 'no_menu': 1 }));
                    }
                });
            return this._super();
        },
    });

    quick_menulist.prototype.sequence = 100;
    SystrayMenu.Items.push(quick_menulist);
    return {
        quick_menulist: quick_menulist,
    };
});